pub struct ArrayView2<'a, T> { /* private fields */ }Expand description
Immutable 2D array view.
Implementations
Sourceimpl<'a, T> ArrayView2<'a, T>
impl<'a, T> ArrayView2<'a, T>
Sourcepub fn new(
data: &'a [T],
shape: [usize; 2],
strides: [isize; 2],
offset: isize,
) -> Result<Self>
pub fn new( data: &'a [T], shape: [usize; 2], strides: [isize; 2], offset: isize, ) -> Result<Self>
Create a checked immutable view.
Sourcepub fn row_stride(&self) -> isize
pub fn row_stride(&self) -> isize
Distance in elements between consecutive rows.
Sourcepub fn col_stride(&self) -> isize
pub fn col_stride(&self) -> isize
Distance in elements between consecutive columns.
Sourcepub fn leading_dimension(&self) -> isize
pub fn leading_dimension(&self) -> isize
Leading dimension for the current row-major-style view.
Sourcepub fn is_contiguous(&self) -> bool
pub fn is_contiguous(&self) -> bool
Whether the view is compact row-major contiguous.
Sourcepub fn as_slice(&self) -> Option<&'a [T]>
pub fn as_slice(&self) -> Option<&'a [T]>
Borrow the backing slice if this view covers it contiguously.
Sourcepub fn get(&self, row: usize, col: usize) -> Option<&'a T>
pub fn get(&self, row: usize, col: usize) -> Option<&'a T>
Get a copied reference at (row, col).
Sourcepub fn row_slice(&self, row: usize) -> Result<Option<&'a [T]>>
pub fn row_slice(&self, row: usize) -> Result<Option<&'a [T]>>
Borrow a row as a contiguous slice when the row layout permits it.
Sourcepub fn rows_range(&self, start: usize, end: usize) -> Result<Self>
pub fn rows_range(&self, start: usize, end: usize) -> Result<Self>
Slice a half-open row range.
Sourcepub fn cols_range(&self, start: usize, end: usize) -> Result<Self>
pub fn cols_range(&self, start: usize, end: usize) -> Result<Self>
Slice a half-open column range.
Sourceimpl<T: Clone> ArrayView2<'_, T>
impl<T: Clone> ArrayView2<'_, T>
Sourcepub fn to_row_major(&self) -> Array2<T>
pub fn to_row_major(&self) -> Array2<T>
Copy this view into compact row-major storage.
Sourcepub fn to_col_major_vec(&self) -> Vec<T>
pub fn to_col_major_vec(&self) -> Vec<T>
Copy this view into a column-major vector.