ArrayViewMut2

Struct ArrayViewMut2 

pub struct ArrayViewMut2<'a, T> { /* private fields */ }
Mutable 2D array view.

Implementations

Source

impl<'a, T> ArrayViewMut2<'a, T>

pub fn new( data: &'a mut [T], shape: [usize; 2], strides: [isize; 2], offset: isize, ) -> Result<Self>

Create a checked mutable view.

pub fn shape(&self) -> [usize; 2]

Shape as [rows, cols].

pub fn rows(&self) -> usize

Number of rows.

pub fn cols(&self) -> usize

Number of columns.

pub fn strides(&self) -> [isize; 2]

Strides in elements.

pub fn row_stride(&self) -> isize

Distance in elements between consecutive rows.

pub fn col_stride(&self) -> isize

Distance in elements between consecutive columns.

pub fn leading_dimension(&self) -> isize

Leading dimension for the current row-major-style view.

pub fn len(&self) -> usize

Number of elements in the logical view.

pub fn is_empty(&self) -> bool

Whether the logical view has no elements.

pub fn is_contiguous(&self) -> bool

Whether the view is compact row-major contiguous.

pub fn as_view(&self) -> ArrayView2<'_, T>

Immutable view over the same region.

pub fn as_mut_slice(&mut self) -> Option<&mut [T]>

Borrow the backing slice if this view covers it contiguously.

pub fn get(&self, row: usize, col: usize) -> Option<&T>

Get an immutable element reference.

pub fn get_mut(&mut self, row: usize, col: usize) -> Option<&mut T>

Get a mutable element reference.

pub fn transpose(self) -> Self

Return a transpose view without copying.

pub fn row_mut(&mut self, row: usize) -> Result<ArrayViewMut2<'_, T>>

Return a mutable row view as a one-row matrix.

pub fn row_slice_mut(&mut self, row: usize) -> Result<Option<&mut [T]>>

Borrow a mutable row as a contiguous slice when the row layout permits it.

pub fn col_mut(&mut self, col: usize) -> Result<ArrayViewMut2<'_, T>>

Return a mutable column view as an rows x 1 matrix.

pub fn rows_range_mut( &mut self, start: usize, end: usize, ) -> Result<ArrayViewMut2<'_, T>>

Slice a mutable half-open row range.

pub fn cols_range_mut( &mut self, start: usize, end: usize, ) -> Result<ArrayViewMut2<'_, T>>

Slice a mutable half-open column range.

Source

impl<T: Clone> ArrayViewMut2<'_, T>

pub fn to_row_major(&self) -> Array2<T>

Copy this view into compact row-major storage.

pub fn to_col_major_vec(&self) -> Vec<T>

Copy this view into a column-major vector.

pub fn copy_from_view(&mut self, other: ArrayView2<'_, T>) -> Result<()>

Copy values from another view with the same shape.